<?php

namespace Pinpoint\BannerManager\Block\Adminhtml\Banner;

use Magento\Framework\View\Element\Template;

/**
 * Class Edit
 * @package Pinpoint\BannerManager\Block\Adminhtml
 */
class Edit extends Template
{
    /**
     * @var \Pinpoint\BannerManager\Model\Banner
     */
    protected $banner;

    /**
     * @var \Pinpoint\BannerManager\Model\BannerBlock
     */
    protected $bannerBlocks;

    /**
     * Edit constructor.
     * @param Template\Context $context
     * @param \Pinpoint\BannerManager\Model\Banner $banner
     * @param \Pinpoint\BannerManager\Model\BannerBlock $bannerBlocks
     * @param array $data
     */
    public function __construct(
        Template\Context $context,
        \Pinpoint\BannerManager\Model\Banner $banner,
        \Pinpoint\BannerManager\Model\BannerBlock $bannerBlocks,
        array $data = []
    ) {
        $this->banner = $banner;
        $this->bannerBlocks = $bannerBlocks;

        parent::__construct($context, $data);
        $this->loadBanner();
    }

    /**
     * @return void
     */
    public function loadBanner()
    {
        $bannerId = $this->getRequest()->getParam('id');

        $this->banner = $this->banner->load($bannerId);
        $this->bannerBlocks = $this->bannerBlocks
            ->getCollection()->addFieldToFilter('banner_id', $bannerId)->setOrder('id', 'asc')->getItems();
    }

    /**
     * @return \Pinpoint\BannerManager\Model\Banner
     */
    public function getBanner()
    {
        return $this->banner;
    }

    /**
     * @return \Pinpoint\BannerManager\Model\BannerBlock
     */
    public function getBannerBlocks()
    {
        return $this->bannerBlocks;
    }

    /**
     * @param $blockId
     * @return null|int
     */
    public function getBlockWidth($blockId)
    {
        $layout = json_decode($this->getBanner()->getData('banner_content'), true);

        foreach ($layout as $blockLayout) {
            if ($blockLayout['id'] == $blockId) {
                return $blockLayout['width'];
            }
        }

        return null;
    }

    /**
     * @param $blockId
     * @return null|int
     */
    public function getBlockHeight($blockId)
    {
        $layout = json_decode($this->getBanner()->getData('banner_content'), true);

        foreach ($layout as $blockLayout) {
            if ($blockLayout['id'] == $blockId) {
                return $blockLayout['height'];
            }
        }

        return null;
    }

    /**
     * @param $blockId
     * @return null|int
     */
    public function getBlockX($blockId)
    {
        $layout = json_decode($this->getBanner()->getData('banner_content'), true);

        foreach ($layout as $blockLayout) {
            if ($blockLayout['id'] == $blockId) {
                return $blockLayout['x'];
            }
        }

        return null;
    }

    /**
     * @param $blockId
     * @return null|int
     */
    public function getBlockY($blockId)
    {
        $layout = json_decode($this->getBanner()->getData('banner_content'), true);

        foreach ($layout as $blockLayout) {
            if ($blockLayout['id'] == $blockId) {
                return $blockLayout['y'];
            }
        }

        return null;
    }

    /**
     * @param $blockRef
     * @return string
     */
    public function blockRefToId($blockRef)
    {
        return explode('_', $blockRef)[1];
    }

    /**
     * @return array
     */
    public function getLocalStorageData()
    {
        $localStorage = [];

        foreach($this->bannerBlocks as $block) {
            $localStorage[$block->getData('block_ref')] = [
                ['name' => 'block_image_url', 'value' => $block->getData('image')],
                ['name' => 'block_image_location', 'value' => 'top_right'],
                ['name' => 'block_text', 'value' => ($block->getData('text'))],
                ['name' => 'block_link_text', 'value' => $block->getData('link_text')],
                ['name' => 'block_text_location', 'value' => $block->getData('text_position')],
                ['name' => 'block_text_colour', 'value' => $block->getData('text_colour')],
                ['name' => 'block_link_url', 'value' => $block->getData('link_url')],
                ['name' => 'block_link_target', 'value' => $block->getData('link_target')],
                ['name' => 'block_text_size', 'value' => $block->getData('block_text_size')],
                ['name' => 'hide_on_mobile', 'value' => $block->getData('hide_on_mobile')],
                ['name' => 'block_image_location', 'value' => $block->getData('block_image_location')]
            ];
        }

        return $localStorage;
    }
}