<?php

namespace Pinpoint\BannerManager\Controller\Adminhtml\Banners;

use Magento\Backend\App\Action;
use Magento\Backend\App\Action\Context;
use Magento\Framework\App\Filesystem\DirectoryList;

/**
 * Class ImageUpload
 * @package Pinpoint\BannerManager\Controller\Adminhtml\Banners
 */
class ImageUpload extends Action
{
    /**
     * @var \Magento\Framework\Filesystem
     */
    protected $_filesystem;

    /**
     * @var \Magento\MediaStorage\Model\File\Uploader
     */
    protected $uploader;

    /**
     * @var \Magento\Framework\Controller\Result\JsonFactory
     */
    protected $resultJsonFactory;

    /**
     * @var \Magento\Store\Model\StoreManagerInterface
     */
    protected $storeManager;

    /**
     * ImageUpload constructor.
     * @param Context $context
     * @param \Magento\Framework\Filesystem $fileSystem
     * @param \Magento\MediaStorage\Model\File\UploaderFactory $uploader
     * @param \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory
     */
    public function __construct(
        Context $context,
        \Magento\Framework\Filesystem $fileSystem,
        \Magento\MediaStorage\Model\File\UploaderFactory $uploader,
        \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory,
        \Magento\Store\Model\StoreManagerInterface $storeManager
    ) {
        $this->_filesystem = $fileSystem;
        $this->uploader = $uploader;
        $this->resultJsonFactory = $resultJsonFactory;
        $this->storeManager = $storeManager;

        parent::__construct($context);
    }

    /**
     * Check the permission to run it
     *
     * @return boolean
     */
    protected function _isAllowed()
    {
        return $this->_authorization->isAllowed('Pinpoint_BannerManager::bannermanager');
    }

    /**
     * @return \Magento\Framework\Controller\Result\Json
     */
    public function execute()
    {
        /** @var \Magento\Framework\Controller\Result\Json $resultPage */
        $resultPage = $this->resultJsonFactory->create();
        if ($_FILES['block_image_upload_file']['name']) {
            try {
                $uploader = $this->uploader->create(['fileId' => 'block_image_upload_file']);
                $uploader->setAllowedExtensions(['jpg', 'jpeg', 'gif', 'png']);
                $uploader->setAllowRenameFiles(true);
                $uploader->setFilesDispersion(true);
                // get media directory
                $mediaDirectory = $this->_filesystem->getDirectoryRead(DirectoryList::MEDIA);
                // save the image to media directory
                $savePath = $mediaDirectory->getAbsolutePath() . 'pinpoint' . DIRECTORY_SEPARATOR;
                $save = $uploader->save($savePath, md5(rand() . time() . uniqid()) . "." . $uploader->getFileExtension());

                $save['file'] = DIRECTORY_SEPARATOR . 'pub' . DIRECTORY_SEPARATOR . 'media' . DIRECTORY_SEPARATOR . 'pinpoint' . $save['file'];
            } catch (Exception $e) {
                \Zend_Debug::dump($e->getMessage());
            }
        }
        return $resultPage->setData(['success' => true, 'file' => $save]);
    }

    /**
     * @return bool
     */
    public function _processUrlKeys()
    {
        return true;
    }
}
